@@ -17,7 +17,7 @@ with 'Bubblegum::Object::Role::Value';
 
 our @ISA = (); # non-object
 
-our $VERSION = '0.41'; # VERSION
+our $VERSION = '0.42'; # VERSION
 
 sub append {
     return $_[0] = CORE::join ' ', map type_string($_), @_;
@@ -256,7 +256,7 @@ Bubblegum::Object::String - Common Methods for Operating on Strings
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 SYNOPSIS
 
@@ -649,13 +649,151 @@ The words method splits the subject into a list of strings, separating each
 group of characters by 1 or more consecutive spaces, and returns that list as an
 array reference.
 
+=head1 COERCIVE METHODS
+
+=head2 to_array
+
+    my $string = "foobar";
+    my $result = $string->to_array; # ["foobar"]
+
+The to_array method coerces a number to an array value. This method returns an
+array reference using the subject as the first element.
+
+=head2 to_a
+
+    my $string = "foobar";
+    my $result = $string->to_a; # ["foobar"]
+
+The to_a method coerces a number to an array value. This method returns an array
+reference using the subject as the first element.
+
+=head2 to_code
+
+    my $string = "foobar";
+    my $result = $string->to_code; # sub { $string }
+
+The to_code method coerces a number to a code value. The code reference, when
+executed, will return the subject.
+
+=head2 to_c
+
+    my $string = "foobar";
+    my $result = $string->to_c; # sub { $string }
+
+The to_c method coerces a number to a code value. The code reference, when
+executed, will return the subject.
+
+=head2 to_hash
+
+    my $string = "foobar";
+    my $result = $string->to_hash; # {"foobar"=>1}
+
+The to_hash method coerces a number to a hash value. This method returns a hash
+reference with a single element using the subject as the key, and the number 1
+as the value.
+
+=head2 to_h
+
+    my $string = "foobar";
+    my $result = $string->to_h; # {"foobar"=>1}
+
+The to_h method coerces a number to a hash value. This method returns a hash
+reference with a single element using the subject as the key, and the number 1
+as the value.
+
+=head2 to_number
+
+    my $string = "foobar";
+    my $result = $string->to_number; # 0
+
+The to_number method coerces a number to a number value. This method returns a
+number comprised of numeric characters extracted from the subject.
+
+=head2 to_n
+
+    my $string = "foobar";
+    my $result = $string->to_n; # 0
+
+The to_n method coerces a number to a number value. This method returns a number
+comprised of numeric characters extracted from the subject.
+
+=head2 to_string
+
+    my $string = "foobar";
+    my $result = $string->to_string; # "foobar"
+
+The to_string method coerces a number to a string value. This method returns a
+string representation of the subject.
+
+=head2 to_s
+
+    my $string = "foobar";
+    my $result = $string->to_s; # "foobar"
+
+The to_s method coerces a number to a string value. This method returns a string
+representation of the subject.
+
+=head2 to_undef
+
+    my $string = "foobar";
+    my $result = $string->to_undef; # undef
+
+The to_undef method coerces a number to an undef value. This method merely
+returns an undef value.
+
+=head2 to_u
+
+    my $string = "foobar";
+    my $result = $string->to_u; # undef
+
+The to_u method coerces a number to an undef value. This method merely returns
+an undef value.
+
 =head1 SEE ALSO
 
-L<Bubblegum::Object::Array>, L<Bubblegum::Object::Code>,
-L<Bubblegum::Object::Hash>, L<Bubblegum::Object::Instance>,
-L<Bubblegum::Object::Integer>, L<Bubblegum::Object::Number>,
-L<Bubblegum::Object::Scalar>, L<Bubblegum::Object::String>,
-L<Bubblegum::Object::Undef>, L<Bubblegum::Object::Universal>,
+=over 4
+
+=item *
+
+L<Bubblegum::Object::Array>
+
+=item *
+
+L<Bubblegum::Object::Code>
+
+=item *
+
+L<Bubblegum::Object::Hash>
+
+=item *
+
+L<Bubblegum::Object::Instance>
+
+=item *
+
+L<Bubblegum::Object::Integer>
+
+=item *
+
+L<Bubblegum::Object::Number>
+
+=item *
+
+L<Bubblegum::Object::Scalar>
+
+=item *
+
+L<Bubblegum::Object::String>
+
+=item *
+
+L<Bubblegum::Object::Undef>
+
+=item *
+
+L<Bubblegum::Object::Universal>
+
+=back
 
 =head1 AUTHOR
 
