@@ -8,7 +8,7 @@ use Moo 'with';
 
 with 'Bubblegum::Role::Configuration';
 
-our $VERSION = '0.41'; # VERSION
+our $VERSION = '0.42'; # VERSION
 
 sub import {
     my $target = caller;
@@ -46,7 +46,7 @@ Bubblegum::Singleton - Singleton Pattern for Bubblegum via Moo
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 SYNOPSIS
 
@@ -65,7 +65,7 @@ And elsewhere:
     $config->hostname('example.com');
 
     $config = Configuration->new;
-    say $config->example; # example.com
+    say $config->hostname; # example.com
 
     $config = $config->renew;
     say $config->hostname; # localhost
